pub struct RedisConnectionManager {
pub redis_client: RedisClient,
}Fields
redis_client: RedisClientTrait Implementations
Sourceimpl Clone for RedisConnectionManager
impl Clone for RedisConnectionManager
Sourcefn clone(&self) -> RedisConnectionManager
fn clone(&self) -> RedisConnectionManager
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ManageConnection for RedisConnectionManager
impl ManageConnection for RedisConnectionManager
Sourcetype Connection = RedisConnection
type Connection = RedisConnection
The connection type this manager deals with.
Sourcetype Error = RedisError
type Error = RedisError
The error type returned by
Connections.Sourcefn connect(&self) -> Result<RedisConnection, Self::Error>
fn connect(&self) -> Result<RedisConnection, Self::Error>
Attempts to create a new connection.
Sourcefn is_valid(&self, conn: &mut RedisConnection) -> Result<(), Self::Error>
fn is_valid(&self, conn: &mut RedisConnection) -> Result<(), Self::Error>
Determines if the connection is still connected to the database. Read more
Sourcefn has_broken(&self, conn: &mut RedisConnection) -> bool
fn has_broken(&self, conn: &mut RedisConnection) -> bool
Quickly determines if the connection is no longer usable. Read more